@@ -1,3 +1,3 @@
 from overrides_extension.enforce import EnforceOverrides
 from overrides_extension.final import final
-from overrides_extension.override import __VERSION__, override
+from overrides_extension.override import override
